# Installation

To install `esssans` and all of its dependencies, use

`````{tab-set}
````{tab-item} pip
```sh
pip install esssans
```
````
````{tab-item} conda
```sh
conda install -c conda-forge -c scipp esssans
```
````
`````
